@@ -484,23 +484,41 @@ class BottleWrapper(cxobjc.Proxy):
         else:
             self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_DISABLED
 
-    @cxobjc.namedSelector(b'enableESync')
-    def enable_esync(self):
+    @cxobjc.python_method
+    def _enable_esync(self):
         if self.is_msync_enabled():
-            self.disable_msync()
+            self._disable_msync()
 
         self.set_config_value("EnvironmentVariables", "WINEESYNC", "1")
         self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_ENABLED
 
         self.bottle_changed()
 
-    @cxobjc.namedSelector(b'disableESync')
-    def disable_esync(self):
+    @cxobjc.namedSelector(b'enableESync')
+    def enable_esync(self):
+        def quit_callback():
+            self._enable_esync()
+            self.resume()
+
+        self.suspend()
+        self.quit(quit_callback)
+
+    @cxobjc.python_method
+    def _disable_esync(self):
         self.set_config_value("EnvironmentVariables", "WINEESYNC", "0")
         self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_DISABLED
 
         self.bottle_changed()
 
+    @cxobjc.namedSelector(b'disableESync')
+    def disable_esync(self):
+        def quit_callback():
+            self._disable_esync()
+            self.resume()
+
+        self.suspend()
+        self.quit(quit_callback)
+
     @cxobjc.python_method
     def is_esync_enabled(self):
         return self.is_esync_enabled_state == BottleWrapper.STATUS_ESYNC_ENABLED
@@ -580,23 +598,41 @@ class BottleWrapper(cxobjc.Proxy):
         else:
             self.is_msync_enabled_state = BottleWrapper.STATUS_MSYNC_DISABLED
 
-    @cxobjc.namedSelector(b'enableMSync')
-    def enable_msync(self):
+    @cxobjc.python_method
+    def _enable_msync(self):
         if self.is_esync_enabled():
-            self.disable_esync()
+            self._disable_esync()
 
         self.set_config_value("EnvironmentVariables", "WINEMSYNC", "1")
         self.is_msync_enabled_state = BottleWrapper.STATUS_MSYNC_ENABLED
 
         self.bottle_changed()
 
-    @cxobjc.namedSelector(b'disableMSync')
-    def disable_msync(self):
+    @cxobjc.namedSelector(b'enableMSync')
+    def enable_msync(self):
+        def quit_callback():
+            self._enable_msync()
+            self.resume()
+
+        self.suspend()
+        self.quit(quit_callback)
+
+    @cxobjc.python_method
+    def _disable_msync(self):
         self.set_config_value("EnvironmentVariables", "WINEMSYNC", "0")
         self.is_msync_enabled_state = BottleWrapper.STATUS_MSYNC_DISABLED
 
         self.bottle_changed()
 
+    @cxobjc.namedSelector(b'disableMSync')
+    def disable_msync(self):
+        def quit_callback():
+            self._disable_msync()
+            self.resume()
+
+        self.suspend()
+        self.quit(quit_callback)
+
     @cxobjc.python_method
     def is_msync_enabled(self):
         return self.is_msync_enabled_state == BottleWrapper.STATUS_MSYNC_ENABLED
