@@ -1147,7 +1147,9 @@ class CrossOver(Gtk.Application):
 
         dialog.set_copyright('© ' + distversion.PRODUCT_COPYRIGHT + '\n\n\n\n\n\n\n\n\n\n\n\n')
         dialog.set_version(distversion.PUBLIC_VERSION)
-        dialog.set_website('https://www.codeweavers.com')
+
+        dialog.set_website('https://www.codeweavers.com/privacy-policy')
+        dialog.set_website_label(_('Privacy Policy'))
 
         try:
             with open(os.path.join(cxutils.CX_ROOT, 'license.txt'), 'r', encoding='utf8') as f:
@@ -1392,7 +1394,7 @@ class CrossOver(Gtk.Application):
         action.set_state(value)
         state = value.get_boolean()
 
-        bottleoperation.set_esync_state(self.selected_bottle, state, self.main_window, self.quit_bottle_callback)
+        bottleoperation.set_esync_state(self.selected_bottle, state, self.main_window)
 
     def on_highres_change_state(self, action, value):
         if self.updating_checkboxes or not self.selected_bottle:
